package com.persagy.service.impl;

import com.persagy.cache.AlarmInfoCache;
import com.persagy.entity.v2.AlarmCondition;
import com.persagy.entity.v2.ObjConditionRel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * 报警条件处理类
 *
 * @author lixing
 * @version V1.0 2021/10/25 10:06 上午
 */
@Service
public class AlarmConditionServiceImpl {
    @Autowired
    AlarmInfoCache alarmInfoCache;

   /**
    * 将报警定义缓存起来
    *
    * @param conditionList 报警定义类别
    * @author lixing
    * @version V1.0 2021/10/25 10:08 上午
    */
    public void cacheAllConditions(List<AlarmCondition> conditionList) {
        // 先清空之前缓存的条件和关联关系
        alarmInfoCache.clear();
        alarmInfoCache.cacheAlarmConditions(conditionList);
    }

    /**
     * 缓存新增的报警条件
     *
     * @param alarmCondition 新增的报警条件
     * @author lixing
     * @version V1.0 2021/10/22 3:21 下午
     */
    public void cacheNewCondition(AlarmCondition alarmCondition) {
        alarmInfoCache.cacheAlarmCondition(alarmCondition);
    }

    /**
     * 缓存更新的报警条件
     *
     * @param alarmCondition 更新的报警条件
     * @author lixing
     * @version V1.0 2021/10/22 3:21 下午
     */
    public void cacheUpdatedCondition(AlarmCondition alarmCondition) {
        alarmInfoCache.cacheAlarmCondition(alarmCondition);
    }

    /**
     * 移除缓存中的报警条件
     *
     * @param alarmCondition 要移除的报警条件
     * @author lixing
     * @version V1.0 2021/10/22 3:21 下午
     */
    public void removeCachedCondition(AlarmCondition alarmCondition) {
        alarmInfoCache.removeCachedAlarmCondition(alarmCondition);
    }

    /**
     * 缓存对象与条件的关联关系
     *
     * @param objConditionRelList 对象与条件的关联关系
     * @author lixing
     * @version V1.0 2021/10/25 10:36 上午
     */
    public void cacheObjConditionRelList(List<ObjConditionRel> objConditionRelList) {
        if (CollectionUtils.isEmpty(objConditionRelList)) {
            return;
        }
        alarmInfoCache.cacheObjConditionRelList(objConditionRelList);
    }

    /**
     * 缓存新增的设备与报警条件关联关系
     *
     * @param objConditionRel 新增的设备与报警条件关联关系
     * @author lixing
     * @version V1.0 2021/10/22 3:21 下午
     */
    public void cacheNewObjConditionRel(ObjConditionRel objConditionRel) {
        alarmInfoCache.cacheObjConditionRel(objConditionRel);
    }

    /**
     * 移除缓存中的设备与报警条件关联关系
     *
     * @param objConditionRel 要移除的关联
     * @author lixing
     * @version V1.0 2021/10/22 3:21 下午
     */
    public void removeCachedObjConditionRel(ObjConditionRel objConditionRel) {
        alarmInfoCache.removeCachedObjConditionRel(objConditionRel);
    }
}
